@@ -8,6 +8,7 @@ use base 'DBIx::Class';
 __PACKAGE__->load_components("InflateColumn::DateTime", "Core");
 __PACKAGE__->table("author");
 __PACKAGE__->add_columns(
+  "author_id" => {},
   "last_name",
   { data_type => "VARCHAR", is_nullable => 0, size => 16 },
   "first_name",
@@ -17,7 +18,7 @@ __PACKAGE__->add_columns(
   "birthdate",
   { data_type => "DATETIME", is_nullable => 0 },
 );
-__PACKAGE__->set_primary_key("first_name", "last_name");
+__PACKAGE__->set_primary_key("author_id");
 #__PACKAGE__->has_many(
 #  "books",
 #  "BookDB::Schema::Result::Book",
@@ -30,4 +31,18 @@ __PACKAGE__->belongs_to(
   { iso => 'country_iso' },
 );
 
+__PACKAGE__->has_many(
+   'author_books',
+   'BookDB::Schema::Result::AuthorBooks',
+   'author_id',
+);
+__PACKAGE__->many_to_many(
+   'books' => 'author_books', 'book'
+);
+
+sub name {
+    my $self = shift;
+    return $self->first_name . " " . $self->last_name;
+}
+
 1;
